@@ -233,7 +233,7 @@ class EmailSender:
                     subject="An email",
                     sender="me@example.com",
                     receivers=['you@example.com'],
-                    test="Hi, this is an email.",
+                    text="Hi, this is an email.",
                     html="<h1>Hi, </h1><p>this is an email.</p>"
                 )
 
@@ -466,4 +466,4 @@ class EmailSender:
         if html_table is not None:
             self.templates_html_table = jinja2.Environment(loader=jinja2.FileSystemLoader(html_table))
         if text_table is not None:
-            self.templates_text_table = jinja2.Environment(loader=jinja2.FileSystemLoader(text_table))
\ No newline at end of file
+            self.templates_text_table = jinja2.Environment(loader=jinja2.FileSystemLoader(text_table))
